@@ -237,7 +237,7 @@ gda_data_model_changed (GdaDataModel *model)
  * @model: a #GdaDataModel object.
  * @row: row number.
  *
- * Emits the 'row_inserted' and 'changed' signals on @model.
+ * Emits the 'row_inserted' signal on @model.
  */
 void
 gda_data_model_row_inserted (GdaDataModel *model, gint row)
@@ -248,8 +248,6 @@ gda_data_model_row_inserted (GdaDataModel *model, gint row)
 		g_signal_emit (G_OBJECT (model),
 			       gda_data_model_signals[ROW_INSERTED],
 			       0, row);
-
-		gda_data_model_changed (model);
 	}
 }
 
@@ -258,7 +256,7 @@ gda_data_model_row_inserted (GdaDataModel *model, gint row)
  * @model: a #GdaDataModel object.
  * @row: row number.
  *
- * Emits the 'row_updated' and 'changed' signals on @model.
+ * Emits the 'row_updated' signal on @model.
  */
 void
 gda_data_model_row_updated (GdaDataModel *model, gint row)
@@ -269,8 +267,6 @@ gda_data_model_row_updated (GdaDataModel *model, gint row)
 		g_signal_emit (G_OBJECT (model),
 			       gda_data_model_signals[ROW_UPDATED],
 			       0, row);
-
-		gda_data_model_changed (model);
 	}
 }
 
@@ -279,7 +275,7 @@ gda_data_model_row_updated (GdaDataModel *model, gint row)
  * @model: a #GdaDataModel object.
  * @row: row number.
  *
- * Emits the 'row_removed' and 'changed' signal on @model.
+ * Emits the 'row_removed' signal on @model.
  */
 void
 gda_data_model_row_removed (GdaDataModel *model, gint row)
@@ -290,8 +286,6 @@ gda_data_model_row_removed (GdaDataModel *model, gint row)
 		g_signal_emit (G_OBJECT (model),
 			       gda_data_model_signals[ROW_REMOVED],
 			       0, row);
-
-		gda_data_model_changed (model);
 	}
 }
 
@@ -561,23 +555,21 @@ gda_data_model_is_editable (GdaDataModel *model)
 /**
  * gda_data_model_append_row
  * @model: a #GdaDataModel object.
- * @values: the row to add.
+ * @values: #GList of #GdaValue* representing the row to add.  The
+ *          length must match model's column count.  These #GdaValue
+ *	    are value-copied.  The user is still responsible for freeing them.
  *
  * Appends a row to the given data model.
  *
- * Returns: the added row.
+ * Returns: the unique ID of the added row.
  */
 const GdaRow *
 gda_data_model_append_row (GdaDataModel *model, const GList *values)
 {
-	const GdaRow *row;
-
 	g_return_val_if_fail (GDA_IS_DATA_MODEL (model), NULL);
 	g_return_val_if_fail (CLASS (model)->append_row != NULL, NULL);
 
-	row = CLASS (model)->append_row (model, values);
-	gda_data_model_row_inserted (model, gda_row_get_number ((GdaRow *) row));
-	return row;
+	return CLASS (model)->append_row (model, values);
 }
 
 /**
@@ -593,18 +585,11 @@ gda_data_model_append_row (GdaDataModel *model, const GList *values)
 gboolean
 gda_data_model_remove_row (GdaDataModel *model, const GdaRow *row)
 {
-	gboolean result;
-
 	g_return_val_if_fail (GDA_IS_DATA_MODEL (model), FALSE);
 	g_return_val_if_fail (row != NULL, FALSE);
 	g_return_val_if_fail (CLASS (model)->remove_row != NULL, FALSE);
 
-	result = CLASS (model)->remove_row (model, row);
-	if (result) {
-		gda_data_model_row_removed (model, gda_row_get_number ((GdaRow *) row));
-	}
-
-	return result;
+	return CLASS (model)->remove_row (model, row);
 }
 
 /**
@@ -620,17 +605,11 @@ gda_data_model_remove_row (GdaDataModel *model, const GdaRow *row)
 gboolean
 gda_data_model_update_row (GdaDataModel *model, const GdaRow *row)
 {
-	gboolean result;
-
 	g_return_val_if_fail (GDA_IS_DATA_MODEL (model), FALSE);
 	g_return_val_if_fail (row != NULL, FALSE);
 	g_return_val_if_fail (CLASS (model)->update_row != NULL, FALSE);
 
-	result = CLASS (model)->update_row (model, row);
-	if (result) {
-		gda_data_model_row_updated (model, gda_row_get_number ((GdaRow *) row));
-	}
-	return result;
+	return CLASS (model)->update_row (model, row);
 }
 
 /**
@@ -659,7 +638,7 @@ gda_data_model_foreach (GdaDataModel *model,
 {
 	gint rows;
 	gint r;
-	const GdaRow *row;
+	GdaRow *row;
 	gboolean more;
 
 	g_return_if_fail (GDA_IS_DATA_MODEL (model));
@@ -670,9 +649,10 @@ gda_data_model_foreach (GdaDataModel *model,
 	for (r = 0; more && r < rows ; r++) {
 		row = gda_data_model_get_row (model, r);
 		/* call the callback function */
-		more = func (model, (GdaRow *) row, user_data);
+		more = func (model, row, user_data);
 	}
 }
+
 /**
  * gda_data_model_is_editing
  * @model: a #GdaDataModel object.
