@@ -21,6 +21,7 @@
 #include <stdio.h>
 #include <syslog.h>
 #include <time.h>
+#include <glib/gmem.h>
 #include <glib/gmessages.h>
 #include <glib/gstrfuncs.h>
 #include <glib/gutils.h>
@@ -134,3 +135,15 @@ gda_log_error (const gchar * format, ...)
 	syslog (LOG_USER | LOG_ERR, msg);
 	g_free (msg);
 }
+
+/**
+ * gda_log_clean_all
+ * @prgname: program name
+ *
+ * Clears the entire log for the given program name.
+ */
+void
+gda_log_clean_all (const gchar * prgname)
+{
+  /* FIXME: implement me */
+}
