@@ -20,7 +20,6 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
 #include <glib/gmessages.h>
 #include <libgda/gda-server-provider.h>
 #include <string.h>
@@ -43,6 +42,14 @@ static GObjectClass *parent_class = NULL;
  * GdaServerProvider class implementation
  */
 
+static gboolean
+_gda_server_provider_create_blob (GdaServerProvider *provider,
+				 GdaConnection *cnc,
+				 GdaBlob *blob)
+{
+	return FALSE;
+}
+
 static void
 gda_server_provider_class_init (GdaServerProviderClass *klass)
 {
@@ -65,6 +72,7 @@ gda_server_provider_class_init (GdaServerProviderClass *klass)
 	klass->rollback_transaction = NULL;
 	klass->supports = NULL;
 	klass->get_schema = NULL;
+	klass->create_blob = _gda_server_provider_create_blob;
 }
 
 static void
@@ -111,7 +119,7 @@ gda_server_provider_get_type (void)
 			0,
 			(GInstanceInitFunc) gda_server_provider_init
 		};
-		type = g_type_register_static (PARENT_TYPE, "GdaServerProvider", &info, 0);
+		type = g_type_register_static (PARENT_TYPE, "GdaServerProvider", &info, G_TYPE_FLAG_ABSTRACT);
 	}
 	return type;
 }
@@ -252,7 +260,7 @@ gda_server_provider_get_database (GdaServerProvider *provider,
  * Proxy the call to the change_database method on the
  " #GdaServerProvider class to the corresponding provider.
  *
- * Returns: TRUE if successful, FALSE otherwise.
+ * Returns: %TRUE if successful, %FALSE otherwise.
  */
 gboolean
 gda_server_provider_change_database (GdaServerProvider *provider,
@@ -276,7 +284,7 @@ gda_server_provider_change_database (GdaServerProvider *provider,
  * Proxy the call to the create_database method on the
  * #GdaServerProvider class to the corresponding provider.
  *
- * Returns: TRUE if successful, FALSE otherwise.
+ * Returns: %TRUE if successful, %FALSE otherwise.
  */
 gboolean
 gda_server_provider_create_database (GdaServerProvider *provider,
@@ -300,7 +308,7 @@ gda_server_provider_create_database (GdaServerProvider *provider,
  * Proxy the call to the drop_database method on the
  * #GdaServerProvider class to the corresponding provider.
  *
- * Returns: TRUE if successful, FALSE otherwise.
+ * Returns: %TRUE if successful, %FALSE otherwise.
  */
 gboolean
 gda_server_provider_drop_database (GdaServerProvider *provider,
@@ -407,3 +415,28 @@ gda_server_provider_get_schema (GdaServerProvider *provider,
 
 	return CLASS (provider)->get_schema (provider, cnc, schema, params);
 }
+
+
+/**
+ * gda_server_provider_create_blob
+ * @provider: a server provider.
+ * @cnc: a #GdaConnection object.
+ * @blob: a user-allocated #GdaBlob structure.
+ *
+ * Creates a BLOB (Binary Large OBject) with read/write access.
+ *
+ * Returns: %FALSE if the database does not support BLOBs. %TRUE otherwise
+ * and the GdaBlob is created and ready to be used.
+ */
+gboolean
+gda_server_provider_create_blob (GdaServerProvider *provider,
+				 GdaConnection *cnc,
+				 GdaBlob *blob)
+{
+	g_return_val_if_fail (GDA_IS_SERVER_PROVIDER (provider), FALSE);
+	g_return_val_if_fail (GDA_IS_CONNECTION (cnc), FALSE);
+	g_return_val_if_fail (blob != NULL, FALSE);
+
+	return CLASS (provider)->create_blob (provider, cnc, blob);
+}
+
